summaryrefslogtreecommitdiffstats
path: root/chrome/common/chrome_switches.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/common/chrome_switches.cc')
-rw-r--r--chrome/common/chrome_switches.cc5
1 files changed, 2 insertions, 3 deletions
diff --git a/chrome/common/chrome_switches.cc b/chrome/common/chrome_switches.cc
index 26f6d6d..705f5a2 100644
--- a/chrome/common/chrome_switches.cc
+++ b/chrome/common/chrome_switches.cc
@@ -540,9 +540,8 @@ const wchar_t kFileDescriptorLimit[] = L"file-descriptor-limit";
// to be sRGB.
const wchar_t kEnableMonitorProfile[] = L"enable-monitor-profile";
-// Enable WebKit's XSSAuditor to mitigate reflective XSS. The XSSAuditor is
-// still experimental.
-const wchar_t kEnableXSSAuditor[] = L"enable-xss-auditor";
+// Disable WebKit's XSSAuditor. The XSSAuditor mitigates reflective XSS.
+const wchar_t kDisableXSSAuditor[] = L"disable-xss-auditor";
#if defined(OS_POSIX)
// A flag, generated internally by Chrome for renderer and other helper process